@@ -61,7 +61,8 @@ class WebViewController extends Controller {
 		private \OCA\Bookmarks\Controller\InternalFoldersController $folderController,
 		private \OCA\Bookmarks\Controller\InternalBookmarkController $bookmarkController,
 		private \OCA\Bookmarks\Controller\InternalTagsController $tagsController,
-		private UserSettingsService $userSettingsService) {
+		private UserSettingsService $userSettingsService,
+	) {
 		parent::__construct($appName, $request);
 		$this->userId = $userId;
 	}
@@ -114,11 +115,11 @@ class WebViewController extends Controller {
 		$userName = 'Unknown';
 		try {
 			/**
-			 * @var $publicFolder PublicFolder
+			 * @var PublicFolder $publicFolder
 			 */
 			$publicFolder = $this->publicFolderMapper->find($token);
 			/**
-			 * @var $folder Folder
+			 * @var Folder $folder
 			 */
 			$folder = $this->folderMapper->find($publicFolder->getFolderId());
 			$title = $folder->getTitle();
@@ -147,7 +148,7 @@ class WebViewController extends Controller {
 	 * @return StreamResponse
 	 */
 	public function serviceWorker(): StreamResponse {
-		$response = new StreamResponse(__DIR__.'/../../js/bookmarks-service-worker.js');
+		$response = new StreamResponse(__DIR__ . '/../../js/bookmarks-service-worker.js');
 		$response->setHeaders(['Content-Type' => 'application/javascript']);
 		$policy = new ContentSecurityPolicy();
 		$policy->addAllowedWorkerSrcDomain("'self'");
@@ -171,8 +172,8 @@ class WebViewController extends Controller {
 			'name' => $this->l->t('Bookmarks'),
 			'short_name' => $this->l->t('Bookmarks'),
 			'start_url' => $this->urlGenerator->linkToRouteAbsolute('bookmarks.web_view.index'),
-			'icons' =>
-				[
+			'icons'
+				=> [
 					[
 						'src' => $this->urlGenerator->linkToRoute('theming.Icon.getTouchIcon',
 							['app' => 'bookmarks']),
